==> haskell-dns-2.0.12-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.12
id: dns-2.0.12-49BCa2yKddp1mBGjC4UViC
key: dns-2.0.12-49BCa2yKddp1mBGjC4UViC
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode
    Network.DNS.Lookup Network.DNS.Resolver Network.DNS.Types
    Network.DNS.Utils
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 358dd95d26fa2fa1ecc2acb41e19b83f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/dns-2.0.12
library-dirs: /usr/lib/ghc-8.2.1/site-local/dns-2.0.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/dns-2.0.12
hs-libraries: HSdns-2.0.12-49BCa2yKddp1mBGjC4UViC
depends:
    base-4.10.0.0 attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j
    binary-0.8.5.1 bytestring-0.10.8.2
    conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz
    conduit-extra-1.1.16-KEf50o5RV3r5Z0A1OmC86V containers-0.5.10.2
    iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=408c5a9ef40ae69c083ed9d4aba83592
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz=04052e0ff779aa08eefa6f6b9de183d0
             conduit-extra-1.1.16-KEf50o5RV3r5Z0A1OmC86V=64aac04225cc01d9fd30f349b8bbb76b
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am=597f66fc6d9460f7765410dd4acfa3cc
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-2.0.12-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.12
id: dns-2.0.12-9IZqdwAbGkyxTkEdYIcHT
key: dns-2.0.12-9IZqdwAbGkyxTkEdYIcHT
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode
    Network.DNS.Lookup Network.DNS.Resolver Network.DNS.Types
    Network.DNS.Utils
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 857bc76779f3f8258f0ae6aa36a7014d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/dns-2.0.12
library-dirs: /usr/lib/ghc-8.2.1/site-local/dns-2.0.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/dns-2.0.12
hs-libraries: HSdns-2.0.12-9IZqdwAbGkyxTkEdYIcHT
depends:
    base-4.10.0.0 attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    binary-0.8.5.1 bytestring-0.10.8.2
    conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz
    conduit-extra-1.1.16-K0CSi1r5Rzl3T85LRH0HhM containers-0.5.10.2
    iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz=04052e0ff779aa08eefa6f6b9de183d0
             conduit-extra-1.1.16-K0CSi1r5Rzl3T85LRH0HhM=a6fea8b9e47bc51138a02f6c74aa4aa3
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am=597f66fc6d9460f7765410dd4acfa3cc
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
